#!/usr/bin/env python
# Demonstration GUI for the SPI protocol implementation.
# Featuring sliders for the PWM control and a checkbox for the LED.
#
# (C) 2004 Chris Liechti <cliechti@gmx.net>
# this is distributed under a free software license, see license.txt
#
# http://mspgcc.sf.net
#
# Requires Python 2.3+ and the msp430 modules, wxPython 2.4+
#
# $Id: spicontrol_gui.py,v 1.1 2004/07/16 01:19:55 cliechti Exp $

import wx
import spicontroller

class MainFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: MainFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        self.panel_1 = wx.Panel(self, -1)
        self.label_1 = wx.StaticText(self.panel_1, -1, "Frequency")
        self.slider_1 = wx.Slider(self.panel_1, -1, 50, 1, 100, style=wx.SL_HORIZONTAL|wx.SL_AUTOTICKS|wx.SL_LABELS)
        self.label_2 = wx.StaticText(self.panel_1, -1, "PWM 1")
        self.slider_2 = wx.Slider(self.panel_1, -1, 10, 0, 100, style=wx.SL_HORIZONTAL|wx.SL_AUTOTICKS|wx.SL_LABELS)
        self.label_3 = wx.StaticText(self.panel_1, -1, "PWM 2")
        self.slider_3 = wx.Slider(self.panel_1, -1, 20, 0, 100, style=wx.SL_HORIZONTAL|wx.SL_AUTOTICKS|wx.SL_LABELS)
        self.checkbox_led = wx.CheckBox(self.panel_1, -1, "LED")

        self.__set_properties()
        self.__do_layout()
        # end wxGlade
        self.__attach_events()
        #init port and hardware
        spicontroller.init()
        #initialize with defaults, so that sliders/LED match with the displayed values
        self.OnSlideFreq()
        self.OnSlidePWM()
        self.OnLED()

    def __set_properties(self):
        # begin wxGlade: MainFrame.__set_properties
        self.SetTitle("SPI Control")
        self.slider_1.SetSize((277, -1))
        self.slider_2.SetSize((277, -1))
        self.slider_3.SetSize((277, -1))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: MainFrame.__do_layout
        sizer_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_2 = wx.BoxSizer(wx.VERTICAL)
        grid_sizer_1 = wx.FlexGridSizer(3, 2, 4, 0)
        grid_sizer_1.Add(self.label_1, 0, wx.ALL, 4)
        grid_sizer_1.Add(self.slider_1, 1, 0, 0)
        grid_sizer_1.Add(self.label_2, 0, wx.ALL, 4)
        grid_sizer_1.Add(self.slider_2, 1, 0, 0)
        grid_sizer_1.Add(self.label_3, 0, wx.ALL, 4)
        grid_sizer_1.Add(self.slider_3, 1, 0, 0)
        sizer_2.Add(grid_sizer_1, 0, wx.ALL, 4)
        sizer_2.Add(self.checkbox_led, 0, wx.ALL, 4)
        self.panel_1.SetAutoLayout(1)
        self.panel_1.SetSizer(sizer_2)
        sizer_2.Fit(self.panel_1)
        sizer_2.SetSizeHints(self.panel_1)
        sizer_1.Add(self.panel_1, 1, wx.EXPAND, 0)
        self.SetAutoLayout(1)
        self.SetSizer(sizer_1)
        sizer_1.Fit(self)
        sizer_1.SetSizeHints(self)
        self.Layout()
        # end wxGlade

    def __attach_events(self):
        #~ wx.EVT_CLOSE(self, self.onWindowClose)
        wx.EVT_SLIDER(self, self.slider_1.GetId(), self.OnSlideFreq)
        wx.EVT_SLIDER(self, self.slider_2.GetId(), self.OnSlidePWM)
        wx.EVT_SLIDER(self, self.slider_3.GetId(), self.OnSlidePWM)
        wx.EVT_CHECKBOX(self, self.checkbox_led.GetId(), self.OnLED)

    def OnSlideFreq(self, event=None):
        spicontroller.setFreq(self.slider_1.GetValue()*65535/100)
    
    def OnSlidePWM(self, event=None):
        spicontroller.setPwm(self.slider_2.GetValue()*65535/100, self.slider_3.GetValue()*65535/100)

    def OnLED(self, event=None):
        spicontroller.setLed(self.checkbox_led.GetValue())

# end of class MainFrame


class MyApp(wx.App):
    def OnInit(self):
        wx.InitAllImageHandlers()
        frame_1 = MainFrame(None, -1, "")
        self.SetTopWindow(frame_1)
        frame_1.Show(1)
        return 1

# end of class MyApp

if __name__ == "__main__":
    app = MyApp(0)
    app.MainLoop()
