; THIS PROGRAM IS PROVIDED "AS IS". TI MAKES NO WARRANTIES OR
; REPRESENTATIONS, EITHER EXPRESS, IMPLIED OR STATUTORY, 
; INCLUDING ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS 
; FOR A PARTICULAR PURPOSE, LACK OF VIRUSES, ACCURACY OR 
; COMPLETENESS OF RESPONSES, RESULTS AND LACK OF NEGLIGENCE. 
; TI DISCLAIMS ANY WARRANTY OF TITLE, QUIET ENJOYMENT, QUIET 
; POSSESSION, AND NON-INFRINGEMENT OF ANY THIRD PARTY 
; INTELLECTUAL PROPERTY RIGHTS WITH REGARD TO THE PROGRAM OR 
; YOUR USE OF THE PROGRAM.
;
; IN NO EVENT SHALL TI BE LIABLE FOR ANY SPECIAL, INCIDENTAL, 
; CONSEQUENTIAL OR INDIRECT DAMAGES, HOWEVER CAUSED, ON ANY 
; THEORY OF LIABILITY AND WHETHER OR NOT TI HAS BEEN ADVISED 
; OF THE POSSIBILITY OF SUCH DAMAGES, ARISING IN ANY WAY OUT 
; OF THIS AGREEMENT, THE PROGRAM, OR YOUR USE OF THE PROGRAM. 
; EXCLUDED DAMAGES INCLUDE, BUT ARE NOT LIMITED TO, COST OF 
; REMOVAL OR REINSTALLATION, COMPUTER TIME, LABOR COSTS, LOSS 
; OF GOODWILL, LOSS OF PROFITS, LOSS OF SAVINGS, OR LOSS OF 
; USE OR INTERRUPTION OF BUSINESS. IN NO EVENT WILL TI'S 
; AGGREGATE LIABILITY UNDER THIS AGREEMENT OR ARISING OUT OF 
; YOUR USE OF THE PROGRAM EXCEED FIVE HUNDRED DOLLARS 
; (U.S.$500).
;
; Unless otherwise stated, the Program written and copyrighted 
; by Texas Instruments is distributed as "freeware".  You may, 
; only under TI's copyright in the Program, use and modify the 
; Program without any charge or restriction.  You may 
; distribute to third parties, provided that you transfer a 
; copy of this license to the third party and the third party 
; agrees to these terms by its first use of the Program. You 
; must reproduce the copyright notice and any other legend of 
; ownership on each copy or partial copy, of the Program.
;
; You acknowledge and agree that the Program contains 
; copyrighted material, trade secrets and other TI proprietary 
; information and is protected by copyright laws, 
; international copyright treaties, and trade secret laws, as 
; well as other intellectual property laws.  To protect TI's 
; rights in the Program, you agree not to decompile, reverse 
; engineer, disassemble or otherwise translate any object code 
; versions of the Program to a human-readable form.  You agree 
; that in no event will you alter, remove or destroy any 
; copyright notice included in the Program.  TI reserves all 
; rights not specifically granted under this license. Except 
; as specifically provided herein, nothing in this agreement 
; shall be construed as conferring by implication, estoppel, 
; or otherwise, upon you, any license or other right under any 
; TI patents, copyrights or trade secrets.
;
; You may not use the Program in non-TI devices.
;************************************************************************
; MSP430F149 Demo - Data Acquisition with the TLC2551 ADC and TLV5616 DAC
;
;
;              TLC2551         MSP430F149		  
;	   -------------      -------------
;         |             |    |             |
;         |          SDO|--->|P3.2(SOMI)   |
;   CH0~~>|AIN      SCLK|<---|P3.3(UCLK)   |
;         |          /CS|<---|P3.0(GPIO)   |
;         |           FS|<---|P3.5(GPIO)   |
;         |             |    |             |
;         |             |    |             |
;                            |             | 
;                            |             | 
;           TLV5616 DAC      |             | 
;          _____________     |             |  
;         |          SDI|<---|P3.1(SIMO)   |
;         |          /CS|<---|P5.3(GPIO)   |
;         |           FS|<---|P3.5(GPIO)   |
;
; Note:  MSP430F149 is set with 8Mz Resonator in this code.
;
; Assembled with IAR Embedded Workshop for MSP430 Kickstart
; 
; Texas Instruments, Inc.
; Tom Hendrick
; Data Aquisition Applications - Dallas
; Nov. 2001
; Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;************************************************************************
#include <signal.h>
#include <io.h>

#define DUMMY               0x000

;************************************************************************
;Constants
;************************************************************************
           .equ     ADC_CS,0x01	      ; Assign p3.1 to ADC_CS
           .equ     FS,0x10	          ; Assign p3.6 to FS (DAC and ADC)
           .equ     DAC_CS,0x20	      ; Assign p5.4 to DAC_CS


;************************************************************************
;Program Code                    
;************************************************************************
            .section    .text
RESET_ISR: mov     #__stack,R1         ; define stackpointer
           call    #Init_Sys           ; Initialize the MSP430
           call    #Mainloop           ; Run the Main Program
Mainloop:
Read_ADC:  bic.b #ADC_CS,&P3OUT
           mov.b #DUMMY,&U0TXBUF       ; Dummy write to SPI (generates SCLK)
           call #CLEAR
           mov.b &U0RXBUF,R12          ; Store Upper Byte
           mov.b #DUMMY,&U0TXBUF       ; Dummy write to SPI (generates SCLK)
           call	#CLEAR
           mov.b &U0RXBUF,R13          ; Store Lower Byte

           mov.b #0x4, R7
CLK_LOOP:  mov.b #DUMMY,&U0TXBUF       ; Dummy write to SPI
CONV_CLK:  bit.b #0x1,&IFG2            ; TXBUF ready?
           jnc CONV_CLK                ; 1 = ready
           bic.b #0x1,&IFG2
           dec R7
           cmp #0,R7
           jnz CLK_LOOP
           biC.b #ADC_CS,&P3OUT           

;          jmp Mainloop                ; Repeat
; Remove remark from above line to skip transmit back to DAC

Write_DAC: bis.b #0x01,&P3OUT         ; Turn on LED of F149 Board
           swpb	R12                   ; Swap Bytes
           add.w R12, R13
           and.w #0xFFF0, R12         ; Strip trailing bits
           rrc.w	R12           ; Shift data 4 places
           rrc.w	R12           ;	to conform to
           rrc.w	R12           ; DAC input format
           rrc.w	R12           ; Data is shifted!
           and.w #0x0FFF, R12         ; Strip any carries 
           add.w #0x4000, R12         ; Set DAC Fast Mode, 0x4000 

           bic.b #FS,&P3OUT           ; Clear FS to DAC
           bic.b #DAC_CS,&P3OUT       ; Enable /CS to DAC
           bis.b #FS,&P3OUT           ; Toggle FS to prepare DAC
           bic.b #FS,&P3OUT           ; to recieve DATA
           swpb R12	              ; Align MSB First
           mov.b R12,&U0TXBUF         ; Transmit upper Data Byte to DAC
           call #CLEAR
           swpb R12                   ; Prepare Lower Byte
           mov.b R12,&U0TXBUF         ; Transmit lower Data Byte to DAC
           call #CLEAR
           bis.b #DAC_CS,&P3OUT       ; Disable /CS to DAC
           bis.b #FS,&P3OUT           ; Set Frame Sync
           bic.b #0x01,&P3OUT         ; Turn off LED of F149 Board
           jmp Mainloop               ; Repeat
 
;*******************************
; Clear TX Flag
;*******************************
CLEAR:
           bit.b #UTXIFG0,&IFG1       ; TXBUF ready?
           jnc CLEAR                  ; 1 = ready
           bic.b #UTXIFG0,&IFG1
           ret
;************************************************************************
Init_Sys:   ;Modules and Controls Registers set-up subroutine
;************************************************************************
StopWDT:   mov     #WDTPW+WDTHOLD,&WDTCTL  ; Stop Watchdog Timer

SetupClock:
          bic.b #XT2OFF, &BCSCTL1
          bis.b #SELM1+SELS, &BCSCTL2
HF_WAIT:  ;8MHz Crystal used - wait for stabilization
          bic.b #OFIFG,&IFG1
          bit.b #OFIFG,&IFG1
          jnz HF_WAIT
          bic.b #OFIFG,&IFG1              ; Clear Oscillator fault flag
          bit.b #OFIFG,&IFG1              ; Test for clear                              
          bis.b #0x01,&P1DIR	          ; P1 pin 1 set to output (toggle's LED)

Setup_SPI0_Port:
          bis.b #0x0E,&P3SEL	          ; P3.1,2,3 SPI option select
          bis.b #ADC_CS+FS+DAC_CS,&P3DIR  ; /CS, FS = P3 output direction
          bis.b #ADC_CS+FS+DAC_CS,&P3OUT  ; P3.5,6,7 CS & FS set 

SetupInterrupt:
          bic.b #0x02, &P1IFG             ; Clear interrupt flags

SetupSPI0:
          bis.b #0x40,&ME1             ; Enable SPI TX/RX
          mov.b #CHAR+SYNC+MM,&U0CTL   ; 8-bit SPI Master
          bis.b #SSEL0+SSEL1+STC,&U0TCTL
          mov.b #0x2,&U0BR0            ; Set SPI Baud Rate
          mov.b #0x0,&U0BR1            ; This give 4MHz SCLK w/ 8MHz Crystal
          mov.b #0x0,&U0MCTL
          ret
           
;*********************************************************************************
; MSP430x11x1/MSP430F14x Interrupt vectors   
;*********************************************************************************
            .section    .vectors
            .org        RESET_VECTOR
RESET_VEC:  .word       RESET_ISR           ; POR, ext. Reset, Watchdog
