#include <io.h>
;******************************************************************************
;   MSP-FET430x110 Demo - Software SPI Interface with HC164 Shift Register
;
;   Description: Transfer byte data from Data (R4) serially to HC164. Data 
;   incremented in the mainloop, effectively incrementing HC164 QA - QH.
;   ACLK = n/a, MCLK = SMCLK = default DCO ~ 800k 
;
;                MSP430F1121     ^     HC164
;             -----------------  |  ----------
;            |                 | |-|/CLR,B    |  8
;            |             P2.1|-->|CLK     Qx|--\->
;            |             P2.3|-->|A         |
;            |                 |   |          |  
;
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
#define     Data     R4                  
            .equ     CLK,2                  ; P2.1 Serial Clock
            .equ     A,8                    ; P2.3 Data Out

            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize 'x112x stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop Watchdog Timer
SetupP2:    bic.b   #CLK+A,&P2OUT           ; Reset CLK and A
            bis.b   #CLK+A,&P2DIR           ; CLK and A config. as output
            mov.b   #0xFF,Data              ; 
                                            ;
Mainloop:   inc.b   Data                    ; Increment Data value    
            call    #TX_HC164               ; Data --> HC164
            call    #Delay                  ; Wait
            jmp     Mainloop                ; Repeat
                                            ; 
;------------------------------------------------------------------------------ 
TX_HC164:   ;Shift Data (R4) --> HC164
;------------------------------------------------------------------------------ 
            push.b  Data                    ; TOS = Save Data
            push.b  #8                      ; TOS = 8-bit counter   
TX_loop:    bic.b   #A,&P2OUT               ; A reset
            rla.b   Data                    ; Data MSB -> Carry
            jnc     Clk_1                   ;
Out_1:      bis.b   #A,&P2OUT               ; A set
Clk_1:      bis.b   #CLK,&P2OUT             ; SCLK set 
Clk_0:      bic.b   #CLK,&P2OUT             ; SCLK reset
            dec.b   0(R1)                   ; All 8 bits sent?
            jnz     TX_loop                 ;
            incd.w  R1                      ; bit counter off stack
            pop.b   Data                    ; Original data
            ret                             ; Return from subroutine
                                            ;
;------------------------------------------------------------------------------ 
Delay:      ;Software delay
;------------------------------------------------------------------------------ 
            push.w  #0xFFFF                 ; Delay to TOS
L1:         dec.w   0(R1)                   ; Decrement TOS
            jnz     L1                      ; Delay over?
            incd.w  R1                      ; Clean TOS
            ret                             ;
                                            ;
;------------------------------------------------------------------------------ 
;           Interrupt Vectors Used MSP430x11x1          
;------------------------------------------------------------------------------ 
            .section    .vectors
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
