#include <io.h>
;******************************************************************************
;   MSP-FET430x110 Demo - Software Port Interrupt Service on P2.0 
;
;   Description; A hi/low transition on P2.0 will trigger P2_ISR which,
;   toggles P1.0.
;   ACLK = n/a, MCLK = SMCLK = default DCO ~ 800k 
;
;                 MSP430F1121
;             -----------------
;         /|\|              XIN|-  
;          | |                 |
;          --|RST          XOUT|-
;      /|\   |                 |
;       --o--| P2.0        P1.0|-->LED
;      \|/
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupP1:    bis.b   #0x01,&P1DIR            ; P1.0 output
            bis.b   #0x01,&P2IE             ; P2.0 Interrupt enabled
            bis.b   #0x01,&P2IES            ; P2.0 hi/low edge 
            bic.b   #0x01,&P2IFG            ; P2.0 IFG Cleared 
            eint                            ; General enable interrupts
                                            ;
Mainloop:   jmp     Mainloop                ; Do nothing
                                            ;
;----------------------------------------------------------------------------- 
P2_ISR:     ;Debounce P2.0, toggle P1.0 Output         
;----------------------------------------------------------------------------- 
            xor.b   #0x01,&P1OUT            ; P1.0 = toggle
Debounce:   push.w  #10000                  ; Delay TOS 
D1:         dec.w   0(R1)                   ; 
            jnz     D1                      ;
            incd.w  R1                      ; Clean up stack
            bic.b   #0x01,&P2IFG            ; P2.0 IFG Cleared 
            bit.b   #0x01,&P2IN             ; P2.0 still low?
            jnc     Debounce                ;
            reti                            ; Return from ISR
                                            ;
;----------------------------------------------------------------------------- 
;           Interrupt Vectors Used MSP430x11x1         
;----------------------------------------------------------------------------- 
            .section    .vectors
            .org    0x06,0xFF               ; P2.x Vector
            .word   P2_ISR                  ; 
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
