#include <io.h>
;******************************************************************************
;   MSP-FET430x110 Demo - Software Poll P2.0 with Set P1.0 if P2.0 = 1
;
;   Description; Poll P2.0 in a loop, if hi P1.0 is set, if low, P1.0 reset.
;   ACLK = n/a, MCLK = SMCLK = default DCO ~ 800k 
;
;                 MSP430F1121
;             -----------------
;         /|\|              XIN|-  
;          | |                 |
;          --|RST          XOUT|-
;      /|\   |                 |
;       --o--| P2.0        P1.0|-->LED
;      \|/
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupP1:    bis.b   #0x01,&P1DIR            ; P1.0 output
                                            ;				          							  
Mainloop:   bit.b   #0x01,&P2IN             ; P2.0 hi/low?
            jc      ON                      ; jmp--> P2.0 is set
                                            ;
OFF:        bic.b   #0x01,&P1OUT            ; P1.0 = 0 / LED OFF
            jmp     Mainloop                ;  
ON:         bis.b   #0x01,&P1OUT            ; P1.0 = 1 / LED ON
            jmp     Mainloop                ;  
                                            ;
;------------------------------------------------------------------------------
;           Interrupt Vectors Used MSP430x11x1         
;------------------------------------------------------------------------------
            .section    .vectors
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
