#include <io.h>
;******************************************************************************
;   MSP-FET430P120 Demo - ADC10 Output Internal Vref on P2.4 and Osc. on P1.0 
;
;   Description; Output ADC10 internal VRef on P2.4, toggling between two 
;   avaialble options, 2.5v and 1.5v. ADC10OSC also output on P1.0. 
;   //*MSP430F1232 or MSP430F1132 Device Required*//
;
;                MSP430F1232
;             -----------------
;         /|\|              XIN|-  
;          | |                 |
;          --|RST          XOUT|-
;            |                 |
;      VRef<-|A4/P2.4      P1.0|--> ADC10OSC ~ 3.5MHz - 6.5MHz
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupADC10: mov.w   #CONSEQ_2,&ADC10CTL1    ; Repeat single channel
            mov.w   #REFOUT+REFON+MSC+ADC10ON,&ADC10CTL0; ADC10 and VRef on output 
            bis.b   #0x10,&ADC10AE          ; P2.4 = ADC10 option select 
            bis.b   #0x01,&P1DIR            ; P1.0 = output directon 
            bis.b   #0x01,&P1SEL            ; P1.0 = ADC10OSC option select 
                                            ;
Mainloop:   bic.w   #ENC,&ADC10CTL0         ; ADC10 disable
            xor.w   #REF2_5V,&ADC10CTL0     ; Toggle Vref 1.5/2.5V
            bis.w   #ENC+ADC10SC,&ADC10CTL0 ; ADC10 enable, start conversion
Delay:      mov.w   #0x0F,R15               ; Long Delay
            mov.w   #0,R14                  ;
Delay_1:    dec.w   R14                     ;
            sbc.w   R15                     ;
            jnz     Delay_1                 ;
            jmp     Mainloop                ;
                                            ;
;------------------------------------------------------------------------------ 
;           Interrupt Vectors Used MSP430x12x2         
;------------------------------------------------------------------------------ 
            .section    .vectors
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
