#include <io.h>
;******************************************************************************
;   MSP-FET430P120 Demo - Timer_A PWM TA1-2 upmode, DCO SMCLK
;
;   Description; This program will generate a two PWM outputs on P1.2/1.3 using
;   Timer_A in an upmode.  The value in CCR0, 512, defines the period and the 
;   values in CCR1 and CCR1 the duty PWM cycles.  Using ~ 800kHz SMCLK as TACLK,
;   the timer period is ~ 640us with a 75% duty cycle on P1.2 and 25% on P1.3. 
;   SMCLK = MCLK = TACLK = default DCO ~ 800kHz. 
;
;               MSP430F123(2)
;             -----------------
;         /|\|              XIN|-  
;          | |                 |
;          --|RST          XOUT|-
;            |                 |
;            |             P1.2|--> CCR1 - 75% PWM
;            |             P1.3|--> CCR2 - 25% PWM
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupTA:    mov.w   #TASSEL1+TACLR,&TACTL   ; SMCLK, Clear TAR
SetupC0:    mov.w   #512-1,&CCR0            ; PWM Period 
SetupC1:    mov.w   #OUTMOD_7,&CCTL1        ; CCR1 reset/set
            mov.w   #384,&CCR1              ; CCR1 PWM Duty Cycle	  
SetupC2:    mov.w   #OUTMOD_7,&CCTL2        ; CCR2 reset/set
            mov.w   #128,&CCR2              ; CCR2 PWM duty cycle	  
SetupP1:    bis.b   #0x0C,&P1DIR            ; P1.2 and P1.3 output
            bis.b   #0x0C,&P1SEL            ; P1.2 and P1.3 TA1/2 otions
            bis.w   #MC0,&TACTL             ; Start Timer_A in up mode
                                            ;					  
Mainloop:   bis.w   #CPUOFF,R2              ; CPU off
            nop                             ; Required only for C-spy
                                            ;
;------------------------------------------------------------------------------ 
;           Interrupt Vectors Used MSP430x12x(2)           
;------------------------------------------------------------------------------ 
            .section    .vectors
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
