#include <io.h>
;******************************************************************************
;   MSP-FET430P140 Demo  - USART0 SPI Interface to HC164 Shift Register 
;
;   Description: This program demonstrates USART0 in SPI mode, interface to a 
;   'HC164 shift register, transferring a RAM byte Data from 0x200.  Data 
;   value incremented in the mainloop, effectively increment HC164 QA - QH.
;   //**SWRST** please see MSP430x1xx Users Guide for description //
;
;                MSP430F149             
;             -----------------
;         /|\|              XIN|-  
;          | |                 |     ^      HC164
;          --|RST          XOUT|-    |  -------------
;            |                 |     |-|/CLR,B       |  8
;            |       SIMO0/P3.1|------>|A          Qx|--\->
;            |       UCLK0/P3.3|------>|CLK          |
;            |                 |       |             | 
;
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .equ    Data,0x200                  

            .section    .text
RESET:      mov.w   #0xA00,R1               ; Initialize 'F149 stackpointer
            call    #Init_Sys               ; Initialize system
                                            ;
Mainloop:   inc.b   Data                    ; Increment Date value    
            call    #TX_HC164               ; Data --> HC164
            call    #Delay                  ; Wait
            jmp     Mainloop                ; Repeat
                                            ; 
;----------------------------------------------------------------------------- 
TX_HC164:   ;SPI Data  --> HC164
;----------------------------------------------------------------------------- 
TX0:        bit.b   #UTXIFG0,&IFG1          ; USART0 TX buffer ready?
            jz      TX0                     ; Jump --> TX buffer not ready
            mov.b   &0x200,&TXBUF0          ; Byte to SPI TXBUF
            ret                             ; Return from subroutine
                                            ;
;----------------------------------------------------------------------------- 
Delay:      ;Software delay
;----------------------------------------------------------------------------- 
            push.w  #0xFFFF                 ; Delay to TOS
L1:         dec.w   0(R1)                   ; Decrement TOS
            jnz     L1                      ; Delay over?
            incd.w  R1                      ; Clean TOS
            ret                             ;
                                            ;
;----------------------------------------------------------------------------- 
Init_Sys:   ;Subroutine to Initialize MSP430F149 Peripherials
;----------------------------------------------------------------------------- 
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop watchdog timer
SetupP3:    bis.b   #0x0A,&P3SEL            ; P3.1,3 SPI option select
            bis.b   #0x0A,&P3DIR            ; P3.1,3 output direction
SetupSPI:   bis.b   #0x40,&ME1              ; Enable USART0 SPI
            bis.b   #CKPH+SSEL1+SSEL0+STC,&UTCTL0 ;* SMCLK, 3-pin mode
            mov.b   #CHAR+SYNC+MM,&UCTL0    ; 8-bit SPI Master **SWRST**
            mov.b   #0x02,&UBR00            ; SMCLK/2 for baud rate
            clr.b   &UBR10                  ; 
            clr.b   &UMCTL0                 ; Clear modulation
            mov.b   #0xFF,&Data             ; Load inital data
            ret                             ; Return from subroutine
                                            ;
;-----------------------------------------------------------------------------
;           Interrupt Vectors Used MSP430x13x/14x         
;-----------------------------------------------------------------------------
            .section    .vectors
            .org    0x1E,0xFF               ; POR, ext. Reset, Watchdog, Flash
            .word   RESET                   ; 
