#include <io.h>
;******************************************************************************
;   MSP-FET430P140 Demo - Timer_B Toggle P1.0, TBoverflow ISR, 32kHz ACLK
;
;   Description; Toggle P1.0 using using software and the timer_B overflow ISR. 
;   In this example an ISR will trigger when TB overflows.  Inside the ISR P1.0 
;   is toggled.  Toggle rate is exactly 0.25hz.
;   ACLK = TBCLK = 32768, MCLK = SMCLK = DCO ~ 800k 
;   //*An external watch crystal on XIN XOUT is required for ACLK*//	  
;
;                 MSP430F149
;             -----------------
;         /|\|              XIN|-  
;          | |                 | 32kHz 
;          --|RST          XOUT|-
;            |                 |
;            |             P1.0|-->LED
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0xA00,R1               ; Initialize 'F149 stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupTB:    mov.w   #TBSSEL0+TBCLR+TBIE,&TBCTL  ; ACLK, Clr TAR, interrupt
SetupP1:    bis.b   #0x01,&P1DIR            ; P1.0 output 
            bis.w   #MC1,&TBCTL             ; Start timer_B continous mode
            eint                            ; Enable interrupts
                                            ;													  
Mainloop:   bis.w   #LPM3,R2                ; Enter LPM3
            nop                             ; Required only for C-spy
                                            ;
;------------------------------------------------------------------------------ 
TBX_ISR:    ;Common ISR for TBCCR1-4 and overflow
;------------------------------------------------------------------------------ 
            add.w   &TBIV,R0                ; Add Timer_B offset vector
            reti                            ; CCR0 - no source
            reti                            ; CCR1
            reti                            ; CCR2
            reti                            ; CCR3
            reti                            ; CCR4
            reti                            ; CCR5
            reti                            ; CCR6
TB_over:    xor.b   #0x01,&P1OUT            ; Toggle P1.0
            reti                            ; Return from overflow ISR		 
                                            ;
;------------------------------------------------------------------------------ 
;           Interrupt Vectors Used MSP430x13x/14x          
;------------------------------------------------------------------------------ 
            .section    .vectors
            .org    0x18,0xFF               ; Timer_BX Vector
            .word   TBX_ISR                 ; 
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
