#include <io.h>
;******************************************************************************
;   MSP-FET430P140 Demo - USART1 UART 19200 Echo ISR, XT2 HF XTAL SMCLK 
;
;   Description; This program will echo a received character, RX interrupt 
;   service used. XT2 oscillator used in this example.
;   ACLK = MCLK = SMCLK = UCLK1 = XT2 = 8MHz
;   Baud rate divider with 8Mhz XTAL @19200 = 8MHz/19200 = 416.66 ~ 417 (0x1A0)
;   //*An external 8MHz XTAL on X2IN X2OUT is required for ACLK*//	  
;
;                MSP430F149
;             -----------------
;         /|\|             X2IN|-  
;          | |                 | 8Mhz  
;          --|RST         X2OUT|-
;            |                 |
;            |             P3.6|------------>
;            |                 | 19200 - 8N1 
;            |             P3.7|<------------
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0xA00,R1               ; Initialize 'F149 stackpointer
            call    #Init_Sys               ;
                                            ;   
Mainloop:   jmp     Mainloop                ; Do nothing
                                            ;
;------------------------------------------------------------------------------ 
Init_Sys:   ;Initalize MSP430 system
;------------------------------------------------------------------------------ 
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupBC:    bic.b   #XT2OFF,&BCSCTL1        ; XT2on
SetupOsc:   bic.b   #OFIFG,&IFG1            ; Clear OSC fault flag 
            mov.w   #0xFF,R15               ; R15 = Delay 
SetupOsc1:  dec.w   R15                     ; Additional delay to ensure start 
            jnz     SetupOsc1               ;
            bit.b   #OFIFG,&IFG1            ; OSC fault flag set? 
            jnz     SetupOsc                ; OSC Fault, clear flag again 
            bis.b   #SELM1+SELS,BCSCTL2     ; MCLK = SMCLK = XT2 (safe)
                                            ;
SetupUART1: mov.b   #CHAR,&UCTL1            ; 8-bit characters
            mov.b   #SSEL1,&UTCTL1          ; UCLK = SMCLK
            mov.b   #0xA0,&UBR01            ; 8Mhz/19200 ~ 417
            mov.b   #0x01,&UBR11            ; 
            mov.b   #0x00,&UMCTL1           ; no modulation
            bis.b   #UTXE1+URXE1,&ME2       ; Enable USART1 TXD/RXD
            bis.b   #URXIE1,&IE2            ; Enable USART1 RX interrupt
SetupP3:    bis.b   #0xC0,&P3SEL            ; P3.6,7 = USART1 option select
            bis.b   #0x40,&P3DIR            ; P3.6 = output direction 
            eint                            ; General enable interrupts
            ret                             ;
                                            ;
;------------------------------------------------------------------------------ 
USART1_ISR: ;Echo back RXed character, confirm TX buffer is ready first
;------------------------------------------------------------------------------ 
TX2:        bit.b   #UTXIFG1,&IFG2          ; USART1 TX buffer ready?
            jz      TX2                     ; Jump is TX buffer not ready
            mov.b   &RXBUF1,&TXBUF1         ; TX -> RXed character
            reti                            ; 
                                            ;
;------------------------------------------------------------------------------ 
;           Interrupt Vectors Used MSP430x13x/14x        
;------------------------------------------------------------------------------ 
            .section    .vectors
            .org    0x06,0xFF               ; 
            .word   USART1_ISR              ; USART1 receive
            .org    0x1E,0xFF               ; 
            .word   RESET                   ; POR, ext. Reset, Watchdog
