#include <io.h>
;******************************************************************************
;   MSP-FET430P410 Demo - WDT Toggle P5.1 Interval overflow ISR, DCO SMCLK 
;
;   Description; Toggle P5.1 using software timed by the WDT ISR. Toggle rate 
;   is approximately 30ms based on default ~ 800khz DCO/SMCLK clock source 
;   used in this example for the WDT.  
;   ACLK = n/a, MCLK = SMCLK = default DCO
;
;                 MSP430F413
;             -----------------
;         /|\|              XIN|-  
;          | |                 |
;          --|RST          XOUT|-
;            |                 |
;            |             P5.1|-->LED
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0x300,R1               ; Initialize stackpointer
SetupWDT:   mov.w   #WDT_MDLY_32,&WDTCTL    ; WDT ~32ms interval timer 
            bis.b   #WDTIE,&IE1             ; Enable WDT interrupt 
SetupP1:    bis.b   #0x02,&P5DIR            ; P5.1 output
            eint                            ; Enable interrupts
                                            ;						  
Mainloop:   bis.w   #CPUOFF,R2              ; CPU off
            nop                             ; Required for C-spy
                                            ;
;------------------------------------------------------------------------------
WDT_ISR:    ;Toggle P5.1
;------------------------------------------------------------------------------
            xor.b   #0x02,&P5OUT            ; Toggle P5.1
            reti                            ;		 
                                            ;   
;----------------------------------------------------------------------------- 
;           Interrupt Vectors Used MSP430F41x          
;----------------------------------------------------------------------------- 
            .section    .vectors
            .org    0x14,0xFF               ; WDT Vector
            .word   WDT_ISR                 ; 
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
