#include <io.h>
;******************************************************************************
;   MSP-FET430P440 Demo - LCD Put "6543210" on STK/EVK LCD 
;
;   Description; Put "6543210" on MSP-EVK430S320 LCD. 
;   ACLK = LFXT1 = 32768, MCLK = SMCLK = DCO = 32xACLK = 1.048576MHz
;  //*An external watch crystal is required on XIN/XOUT for ACLK*//	  
;
;                 MSP430F449
;             -----------------
;         /|\|              XIN|-  
;          | |                 | 32kHz
;          --|RST          XOUT|-
;            |                 |
;          +-|R33          P5.1|     -----------------
;         1m |              -  |--> | + 7 6 5 4 3 2 1 |
;          +-|R23          P3.2|     -----------------
;         1m |             COM0|-----||||
;          +-|R13          COM1|------|||
;         1m |             COM2|-------||
;          +-|R03          COM3|--------|
;          | |                 |
;         Vss
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0xA00,R1               ; Initialize '449 stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop Watchdog Timer
SetupFLL:   bis.b   #XCAP14PF,&FLL_CTL0     ; Configure load caps
SetupLCD:   mov.b   #LCDON+LCD4MUX+LCDP2,&LCDCTL    ; STK LCD 4Mux, S0-S17
SetupBT:    mov.b   #BTFRFQ1,&BTCTL         ; STK LCD freq. 
SetupIO:    mov.b   #0xFC,&P5SEL            ; Common and Rxx all selected
                                            ;       
Mainloop:   clr.w   R5                      ; Clear pointer
Disp:       mov.b   LCD_Tab(R5),LCDMEM(R5)  ;   
            inc.w   R5                      ; 
            cmp.w   #0x07,R5                ;
            jne     Disp                    ;
            jmp     Mainloop                ; Again
                                            ;
LCD_Tab:    .byte   0xB7                    ; displays "0"
            .byte   0x12                    ; displays "1"
            .byte   0x8F                    ; displays "2"
            .byte   0x1F                    ; displays "3"
            .byte   0x3A                    ; displays "4"
            .byte   0x3D                    ; displays "5"
            .byte   0xBD                    ; displays "6"
            .byte   0x13                    ; displays "7"
            .byte   0xBF                    ; displays "8"
            .byte   0x3F                    ; displays "9"
                                            ;										  
;----------------------------------------------------------------------------- 
;           Interrupt Vectors Used MSP430F44x         
;----------------------------------------------------------------------------- 
            .section    .vectors
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
