#include <io.h>
;******************************************************************************
;   MSP-FET430P440 Demo - FLL+ LPM3 Using BasicTimer ISR, 32kHz ACLK
;  
;   Description: System runs normally in LPM3 with basic timer clocked by 
;   32kHz ACLK. At a 2 second interval the basic timer ISR will wake the 
;   system and flash the LED on P5.1 inside of the Mainloop. If using
;   FET, must release JTAG on go, start, stop and restart application.
;   ACLK = LFXT1 = 32768, MCLK = SMCLK = DCO = 32xACLK = 1.48576MHz
;   //*An external watch crystal is required on XIN/XOUT for ACLK*//	  
;
;                MSP430F449
;             -----------------
;         /|\|              XIN|-  
;          | |                 | 32k
;          --|RST          XOUT|-
;            |                 |
;            |             P5.1|-->LED
;
;   M.Buccini
;   Texas Instruments, Inc
;   January 2002
;   Adapted for mspgcc by Steve Underwood <steveu@coppice.org>
;******************************************************************************
            .section    .text
RESET:      mov.w   #0xA00,R1               ; Initialize '449 stackpointer
StopWDT:    mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT
SetupFLL:   bis.b   #XCAP14PF,&FLL_CTL0     ; Configure load caps
SetupBT:    mov.b   #BTDIV+BTIP2+BTIP1+BTIP0,&BTCTL   ; 2s Int. 
            bis.b   #BTIE,&IE2              ; Enable Basic Timer interrupt        
SetupPx:    mov.b   #0xFF,&P6DIR            ; P6.x output
            mov.b   #0xFF,&P5DIR            ; P5.x output
            mov.b   #0xFF,&P4DIR            ; P4.x output
            mov.b   #0xFF,&P3DIR            ; P3.x output
            mov.b   #0xFF,&P2DIR            ; P2.x output
            mov.b   #0xFF,&P1DIR            ; P1.x output
            eint                            ; Enable interrupts      
                                            ;				          							  
Mainloop:   bis.w   #LPM3,R2                ; Remain in LPM3
            bis.b   #0x02,&P5OUT            ; Set P5.1
            push    #2000                   ; Delay to TOS
Pulse:      dec.w   0(R1)                   ; Decrement Value at TOS
            jnz     Pulse                   ; Delay done?
            incd.w  R1                      ; Clean-up stack
            bic.b   #0x02,&P5OUT            ; Reset P5.1
            jmp     Mainloop                ;
                                            ;
;------------------------------------------------------------------------------
BT_ISR:     ;Exit LPM3 on reti
;------------------------------------------------------------------------------
            bic.w   #LPM3,0(R1)             ; 
            reti                            ;		 
                                            ;   
;----------------------------------------------------------------------------- 
;           Interrupt Vectors Used MSP430x44x         
;----------------------------------------------------------------------------- 
            .section    .vectors
            .org    0x00,0xFF               ; BT Vector
            .word   BT_ISR                  ; 
            .org    0x1E,0xFF               ; MSP430 RESET Vector
            .word   RESET                   ; 
